==> evolution-1.4.11.zip: evolution-1.4.11/manager/includes/lang/errormsg/nederlands-utf8.inc.php <==
<?php
/**
 * MODX error messages language file
 *
 * @version 1.0.13
 * @date 31/12/2013
 *
 * @language Dutch
 * @package modx
 * @subpackage manager
 *
 * Please commit your language changes on Transifex (https://www.transifex.com/projects/p/modx-evolution/) or on GitHub (https://github.com/modxcms/evolution).
 */
$_lang["No errors occured."] = "Er zijn geen fouten.";
$_lang["An error occured!"] = "Er is een fout opgetreden!";
$_lang["You don't have enough privileges for this action!"] = "Je hebt niet genoeg rechten hebt voor deze actie!";
$_lang["ID passed in request is NaN!"] = "doorgegeven ID is NaN!";
$_lang["The document is locked!"] = "Het document is geblokkeerd!";
$_lang["Too many results returned from database!"] = "Te veel resultaten uit de database!";
$_lang["Not enough/ no results returned from database!"] = "Te weinig / geen resultaten terug van database!";
$_lang["Couldn't find parent document's name!"] = "Kon naam bovenliggende document niet vinden!";
$_lang["Logging error!"] = "Inloggen fout!";
$_lang["Table to optimise not found in request!"] = "Tabel optimaliseren niet gevonden in aanvraag!";
$_lang["No settings found in request!"] = "Geen instellingen gevonden in aanvraag!";
$_lang["The document must have a title!"] = "Het document moet een titel hebben!";
$_lang["No user selected as recipient of this message!"] = "Geen gebruiker geselecteerd als ontvanger van dit bericht!";
$_lang["No group selected as recipient of this message!"] = "Geen groep geselecteerd als ontvanger van dit bericht!";
$_lang["The document was not found!"] = "Het document is niet gevonden!";
$_lang["Double action (GET & POST) posted!"] = "Dubbele actie (GET & POST) geplaatst!";
$_lang["Document cannot be it's own parent!"] = "Document kan niet zijn eigen onderliggende document zijn!";
$_lang["Document's ID not passed in request!"] = "Document ID niet doorgegeven in aanvraag!";
$_lang["New parent not set in request!"] = "Nieuwe onderliggende document niet in aanvraag!";
$_lang["don't know the user!" ] = "Onjuiste gebruikersnaam of wachtwoord ingevoerd!";
$_lang["wrong password!"] = "Onjuiste gebruikersnaam of wachtwoord ingevoerd!";
$_lang["Due to too many failed logins, you have been blocked!"] = "Wegens te veel mislukte aanmeldingen ben je geblokkeerd!";
$_lang["You are blocked and cannot log in!"] = "U bent geblokkeerd en kan niet inloggen!";
$_lang["You are blocked and cannot log in! Please try again later."] = "U bent geblokkeerd en kan niet inloggen! Probeer het later opnieuw.";
$_lang["The security code you entered didn't validate! Please try to login again!"] = "De veiligheidscode klopt niet! Probeer het opnieuw!";

==> evolution-1.4.26.zip: evolution-1.4.26/manager/includes/lang/errormsg/nederlands-utf8.inc.php <==
<?php
/**
 * MODX error messages language file
 *
 * @version 1.0.13
 * @date 31/12/2013
 *
 * @language Dutch
 * @package modx
 * @subpackage manager
 *
 * Please commit your language changes on Transifex (https://www.transifex.com/projects/p/modx-evolution/) or on GitHub (https://github.com/modxcms/evolution).
 */
$_lang["No errors occured."] = "Er zijn geen fouten.";
$_lang["An error occured!"] = "Er is een fout opgetreden!";
$_lang["You don't have enough privileges for this action!"] = "Je hebt niet genoeg rechten hebt voor deze actie!";
$_lang["ID passed in request is NaN!"] = "doorgegeven ID is NaN!";
$_lang["The document is locked!"] = "Het document is geblokkeerd!";
$_lang["Too many results returned from database!"] = "Te veel resultaten uit de database!";
$_lang["Not enough/ no results returned from database!"] = "Te weinig / geen resultaten terug van database!";
$_lang["Couldn't find parent document's name!"] = "Kon naam bovenliggende document niet vinden!";
$_lang["Logging error!"] = "Inloggen fout!";
$_lang["Table to optimise not found in request!"] = "Tabel optimaliseren niet gevonden in aanvraag!";
$_lang["No settings found in request!"] = "Geen instellingen gevonden in aanvraag!";
$_lang["The document must have a title!"] = "Het document moet een titel hebben!";
$_lang["No user selected as recipient of this message!"] = "Geen gebruiker geselecteerd als ontvanger van dit bericht!";
$_lang["No group selected as recipient of this message!"] = "Geen groep geselecteerd als ontvanger van dit bericht!";
$_lang["The document was not found!"] = "Het document is niet gevonden!";
$_lang["Double action (GET & POST) posted!"] = "Dubbele actie (GET & POST) geplaatst!";
$_lang["Document cannot be it's own parent!"] = "Document kan niet zijn eigen onderliggende document zijn!";
$_lang["Document's ID not passed in request!"] = "Document ID niet doorgegeven in aanvraag!";
$_lang["New parent not set in request!"] = "Nieuwe onderliggende document niet in aanvraag!";
$_lang["don't know the user!" ] = "Onjuiste gebruikersnaam of wachtwoord ingevoerd of u bent geblokkeerd!";
$_lang["wrong password!"] = "Onjuiste gebruikersnaam of wachtwoord ingevoerd of u bent geblokkeerd!";
$_lang["Due to too many failed logins, you have been blocked!"] = "Onjuiste gebruikersnaam of wachtwoord ingevoerd of u bent geblokkeerd!";
$_lang["You are blocked and cannot log in!"] = "Onjuiste gebruikersnaam of wachtwoord ingevoerd of u bent geblokkeerd!";
$_lang["You are blocked and cannot log in! Please try again later."] = "Onjuiste gebruikersnaam of wachtwoord ingevoerd of u bent geblokkeerd!";
$_lang["The security code you entered didn't validate! Please try to login again!"] = "De veiligheidscode klopt niet! Probeer het opnieuw!";
